/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */


package de.bsvrz.ste.rdstmc.situation;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.Data.Array;
import de.bsvrz.dav.daf.main.config.SystemObject;

public class SituationEigenschaften 
{
  public final long startZeit;
  public final long dauer;
  public final SystemObject[] strassenSegment;
  public final long startOffset;
  public final long endOffset;
    
  SituationEigenschaften(Data datenSatz)
  {
    startZeit = datenSatz.getItem("StartZeit").asTimeValue().getMillis();
    dauer = datenSatz.getItem("Dauer").asTimeValue().getMillis();
    startOffset = datenSatz.getItem("StartOffset").asUnscaledValue().longValue();
    endOffset = datenSatz.getItem("EndOffset").asUnscaledValue().longValue();
    
    Array array = datenSatz.getItem("StraßenSegment").asArray();
    if (array != null)
    {
      strassenSegment = new SystemObject[array.getLength()];
      for (int i = 0; i < array.getLength(); i += 1)
      {
        SystemObject obj = array.getItem(i).asReferenceValue().getSystemObject();
        strassenSegment[i] = obj;
      }
    }
    else
    {
      strassenSegment = new SystemObject[0];
    }
  }

  /**
   * Beschreiben diese Situationseigenschaften eine gültige Situation?
   * @param aktuelleZeit Aktuelle Zeit
   * @return true, wenn diese Situationseigenschaften eine gültige Situation beschreiben,
   * false sonst
   */
  public boolean istGueltig(long aktuelleZeit)
  {
    if (strassenSegment.length == 0)
    {
      return false;
    }
    if (dauer == 0)
    {
      return startZeit <= aktuelleZeit;
    }
    return startZeit + dauer >= aktuelleZeit;
  }
  
}
